Coverage for /root/GitHubProjects/impacket/impacket/examples/ntlmrelayx/utils/__init__.py: 100%

# Coverage for /root/GitHubProjects/impacket/impacket/examples/ntlmrelayx/utils/__init__.py : 100%

## 1 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# Impacket - Collection of Python classes for working with network protocols.

2#

3# SECUREAUTH LABS. Copyright (C) 2021 SecureAuth Corporation. All rights reserved.

4#

5# This software is provided under a slightly modified version

6# of the Apache Software License. See the accompanying LICENSE file

7# for more information.

8#

9 pass